@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -23,20 +26,11 @@ FAILEDOPERATION_APISERVERFAIL = 'FailedOperation.APIServerFail'
 # 客户端已离线。
 FAILEDOPERATION_AGENTOFFLINE = 'FailedOperation.AgentOffline'
 
-# 关闭专业版失败。
-FAILEDOPERATION_CLOSEPROVERSION = 'FailedOperation.CloseProVersion'
-
-# 创建获取端口任务失败。
-FAILEDOPERATION_CREATEOPENPORTTASK = 'FailedOperation.CreateOpenPortTask'
-
-# 创建获取实时进程任务失败。
-FAILEDOPERATION_CREATEPROCESSTASK = 'FailedOperation.CreateProcessTask'
-
 # 导出文件失败。
 FAILEDOPERATION_EXPORT = 'FailedOperation.Export'
 
-# 询价失败。
-FAILEDOPERATION_INQUIRYPRICE = 'FailedOperation.InquiryPrice'
+# 可用license数量不足，缺少1个license，请购买新license。
+FAILEDOPERATION_LICENSEEXCEEDED = 'FailedOperation.LicenseExceeded'
 
 # 卸载主机。
 FAILEDOPERATION_MACHINEDELETE = 'FailedOperation.MachineDelete'
@@ -44,20 +38,11 @@ FAILEDOPERATION_MACHINEDELETE = 'FailedOperation.MachineDelete'
 # 无专业版主机。
 FAILEDOPERATION_NOPROFESSIONHOST = 'FailedOperation.NoProfessionHost'
 
-# 拉取实时端口任务不存在。
-FAILEDOPERATION_OPENPORTTASKNOTFOUND = 'FailedOperation.OpenPortTaskNotFound'
-
-# 开通专业版失败。
-FAILEDOPERATION_OPENPROVERSION = 'FailedOperation.OpenProVersion'
-
 # 多台主机隔离，部分或全部失败。
 FAILEDOPERATION_PARTSEPARATE = 'FailedOperation.PartSeparate'
 
-# 不能关闭预付费模式专业版。
-FAILEDOPERATION_PREPAYMODE = 'FailedOperation.PrePayMode'
-
-# 拉取实时进程任务不存在。
-FAILEDOPERATION_PROCESSTASKNOTFOUND = 'FailedOperation.ProcessTaskNotFound'
+# 开启防护失败。
+FAILEDOPERATION_PROTECTSTARTFAIL = 'FailedOperation.ProtectStartFail'
 
 # 回复木马失败。
 FAILEDOPERATION_RECOVER = 'FailedOperation.Recover'
@@ -65,18 +50,12 @@ FAILEDOPERATION_RECOVER = 'FailedOperation.Recover'
 # 重新检测漏洞失败。
 FAILEDOPERATION_RESCANVUL = 'FailedOperation.RescanVul'
 
-# 该主机已有重新检测任务正在执行中。
-FAILEDOPERATION_RESCANVULPROCESSINUSE = 'FailedOperation.RescanVulProcessInUse'
-
 # 单台主机隔离失败。
 FAILEDOPERATION_SINGLESEPARATE = 'FailedOperation.SingleSeparate'
 
 # 创建基线策略超过上限。
 FAILEDOPERATION_TOOMANYSTRATEGY = 'FailedOperation.TooManyStrategy'
 
-# 交易失败。
-FAILEDOPERATION_TRADEERROR = 'FailedOperation.TradeError'
-
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -107,9 +86,6 @@ INVALIDPARAMETER_NAMEHASREPETITION = 'InvalidParameter.NameHasRepetition'
 # 参数解析错误。
 INVALIDPARAMETER_PARSINGERROR = 'InvalidParameter.ParsingError'
 
-# 端口格式不合法。
-INVALIDPARAMETER_PORTNOVALID = 'InvalidParameter.PortNoValid'
-
 # 正则参数格式错误。
 INVALIDPARAMETER_REGEXRULEERROR = 'InvalidParameter.RegexRuleError'
 
@@ -119,9 +95,15 @@ INVALIDPARAMETER_REVERSHELLKEYFIELDALLEMPTY = 'InvalidParameter.ReverShellKeyFie
 # 规则类接口，主机IP不正确。
 INVALIDPARAMETER_RULEHOSTIPERR = 'InvalidParameter.RuleHostipErr'
 
+# 参数取值错误。
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # 标签名称长度不能超过15个字符。
 INVALIDPARAMETERVALUE_TAGNAMELENGTHLIMIT = 'InvalidParameterValue.TagNameLengthLimit'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 超出批量添加数量。
 LIMITEXCEEDED_AREAQUOTA = 'LimitExceeded.AreaQuota'
 
@@ -131,5 +113,11 @@ MISSINGPARAMETER = 'MissingParameter'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
+
+# 未知参数错误。
+UNKNOWNPARAMETER = 'UnknownParameter'
